/*==============================================================*/
/* DBMS name:      Microsoft SQL Server 2000                    */
/* Created on:     14.02.2010 12:51:26                          */
/*==============================================================*/


alter table DISCOUNT
   drop constraint FK_DISCOUNT_STORE_DIS_STORE
go


alter table PICTURE
   drop constraint FK_PICTURE_AUTHOR_PI_AUTHOR
go


alter table ROYSCHED
   drop constraint FK_ROYSCHED_TITLE_ROY_TITLE
go


alter table SALE
   drop constraint FK_SALE_SALES_TIT_TITLE
go


alter table SALE
   drop constraint FK_SALE_STORE_SAL_STORE
go


alter table TITLE
   drop constraint FK_TITLE_TITLE_PUB_PUBLISHE
go


alter table TITLEAUTHOR
   drop constraint FK_TITLEAUT_RELATION__AUTHOR
go


alter table TITLEAUTHOR
   drop constraint FK_TITLEAUT_RELATION__TITLE
go


if exists (select 1 from sysobjects where id=object_id('R_T_PERCENT') and type='R')
	drop rule  R_T_PERCENT
go


create rule R_T_PERCENT as
      @column is null or (@column between 1 and 100 )
go



/*==============================================================*/
/* Table: AUTHOR                                                */
/*==============================================================*/
create table AUTHOR (
   AU_ID               char(12)      not null,
   AU_LNAME             varchar(40)              not null,
   AU_FNAME             varchar(40)               not null,
   AU_BIOGRAPH          varchar(1)          null,
   AU_ADVANCE           numeric(8,2)             null,
   AU_ADDRESS           varchar(80)              null,
   CITY                 varchar(40)           null,
   STATE                char(2)              null,
   POSTALCODE           char(5)              null,
   AU_PHONE             char(12)             not null,
   constraint PK_AUTHOR primary key  (AU_ID)
)
go


/*==============================================================*/
/* Table: DISCOUNT                                              */
/*==============================================================*/
create table DISCOUNT (
   DISCOUNT_ID          smallint         not null,
   STOR_ID              char(12)      not null,
   DISC_PERCENT          smallint            not null
      constraint CKC_DISC_PERCENT_DISCOUNT check (DISC_PERCENT between 1 and 100),
   DISC_TYPE            varchar(20)         null
      constraint CKC_DISC_TYPE_DISCOUNT check (DISC_TYPE is null or ( DISC_TYPE in ('''High'','''','''Medium'','''','Low') )),
   DISC_LOWQTY          numeric           null,
   DISC_HIGHQTY         numeric           null,
   constraint PK_DISCOUNT primary key  (DISCOUNT_ID)
)
go


/*==============================================================*/
/* Table: PICTURE                                               */
/*==============================================================*/
create table PICTURE (
   PIX_ID                smallint         not null,
   AU_ID               char(12)     null,
   PIX_PICTURE          ntext                not null,
   constraint PK_PICTURE primary key  (PIX_ID)
)
go


/*==============================================================*/
/* Table: PUBLISHER                                             */
/*==============================================================*/
create table PUBLISHER (
   PUB_ID               char(12)      not null,
   PUB_NAME            varchar(40)              null,
   CITY                 varchar(40)         null,
   STATE                char(2)              null,
   constraint PK_PUBLISHER primary key  (PUB_ID)
)
go


/*==============================================================*/
/* Table: ROYSCHED                                              */
/*==============================================================*/
create table ROYSCHED (
   TITLE_ISBN           char(12)             not null,
   ROY_LORANGE          numeric           null,
   ROY_HIRANGE          numeric          null,
   ROY_AMOUNT           numeric(8,2)             null,
   constraint PK_ROYSCHED primary key  (TITLE_ISBN)
)
go


/*==============================================================*/
/* Table: SALE                                                  */
/*==============================================================*/
create table SALE (
   SALE_ID              smallint         not null,
   STOR_ID              char(12)      not null,
   TITLE_ISBN           char(12)             not null,
   SALE_DATE            datetime               not null,
   SALE_AMOUNT         numeric(7,2)             null,
   SALE_TERMS           varchar(80)          null,
   SALE_QTY             numeric           null,
   constraint PK_SALE primary key  (SALE_ID)
)
go


/*==============================================================*/
/* Table: STORE                                                 */
/*==============================================================*/
create table STORE (
   STOR_ID              char(12)      not null,
   STOR_NAME            varchar(40)              null,
   CITY                 varchar(40)         null,
   STATE                char(2)              null,
   POSTALCODE           char(5)              null,
   STOR_ADDRESS        varchar(80)            null,
   constraint PK_STORE primary key  (STOR_ID)
)
go


/*==============================================================*/
/* Table: TITLE                                                 */
/*==============================================================*/
create table TITLE (
   TITLE_ISBN           char(10)             not null,
   PUB_ID              char(12)        not null,
   TITLE_TEXT           varchar(80)          not null,
   TITLE_TYPE           varchar(20)         not null,
   TITLE_PRICE          numeric(8,2)             null,
   TITLE_NOTES         varchar(1)         null,
   TITLE_PUBDATE        datetime               not null,
   PERIODICAL           numeric(1)           null,
   PER_FORMAT           char(20)             null,
   PER_FREQUENCY        char(20)             null,
   NONP_COLLECTION      char(20)          null,
   constraint PK_TITLE primary key  (TITLE_ISBN)
)
go


/*==============================================================*/
/* Table: TITLEAUTHOR                                           */
/*==============================================================*/
create table TITLEAUTHOR (
   AU_ID                char(12)        not null,
   TITLE_ISBN           char(12)             not null,
   TA_ORDER             integer              null,
   TA_PERCENT           smallint            null
      constraint CKC_TA_PERCENT_TITLEAUT check (TA_PERCENT is null or (TA_PERCENT between 1 and 100 )),
   constraint PK_TITLEAUTHOR primary key  (AU_ID, TITLE_ISBN)
)
go


alter table DISCOUNT
   add constraint FK_DISCOUNT_STORE_DIS_STORE foreign key (STOR_ID)
      references STORE (STOR_ID)
go


alter table PICTURE
   add constraint FK_PICTURE_AUTHOR_PI_AUTHOR foreign key (AU_ID)
      references AUTHOR (AU_ID)
go


alter table ROYSCHED
   add constraint FK_ROYSCHED_TITLE_ROY_TITLE foreign key (TITLE_ISBN)
      references TITLE (TITLE_ISBN)
go


alter table SALE
   add constraint FK_SALE_SALES_TIT_TITLE foreign key (TITLE_ISBN)
      references TITLE (TITLE_ISBN)
go


alter table SALE
   add constraint FK_SALE_STORE_SAL_STORE foreign key (STOR_ID)
      references STORE (STOR_ID)
go


alter table TITLE
   add constraint FK_TITLE_TITLE_PUB_PUBLISHE foreign key (PUB_ID)
      references PUBLISHER (PUB_ID)
go


alter table TITLEAUTHOR
   add constraint FK_TITLEAUT_RELATION__AUTHOR foreign key (AU_ID)
      references AUTHOR (AU_ID)
go


alter table TITLEAUTHOR
   add constraint FK_TITLEAUT_RELATION__TITLE foreign key (TITLE_ISBN)
      references TITLE (TITLE_ISBN)
go


